@@ -1,9 +1,9 @@
 #!/bin/sh
-export PATH='/usr/obj/ports/hs-libmpd-0.9.0.6/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/X11R6/bin'
+export PATH='/usr/obj/ports/hs-libmpd-0.9.0.7/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/X11R6/bin'
 echo 'name: libmpd
-version: 0.9.0.6
-id: libmpd-0.9.0.6-ff4801e1edc53566d4a6295fc9bfef4a
-key: libmp_4M6tZyLoNUrEJ5VQyWfvHZ
+version: 0.9.0.7
+id: libmpd-0.9.0.7-F2ZfiW69JTD1yGu4DIm545
+key: libmpd-0.9.0.7-F2ZfiW69JTD1yGu4DIm545
 license: MIT
 copyright: Ben Sinclair 2005-2009, Joachim Fasting 2007-2015,
            Daniel Schoepe 2009, Andrzej Rybczak 2010,
@@ -19,6 +19,7 @@ description:
 category: Network, Sound
 author: Ben Sinclair
 exposed: True
+indefinite: False
 exposed-modules:
     Network.MPD Network.MPD.Applicative
     Network.MPD.Applicative.ClientToClient
@@ -43,24 +44,35 @@ hidden-modules: Network.MPD.Core.Class Network.MPD.Core.Error
                 Network.MPD.Commands.Output Network.MPD.Commands.Reflection
                 Network.MPD.Applicative.Util Network.MPD.Applicative.Internal
                 Network.MPD.Util
+abi: 9757efe7c4d4f59902da6522960f40fe
 trusted: False
-import-dirs: /usr/local/lib/ghc/libmpd-0.9.0.6
-library-dirs: /usr/local/lib/ghc/libmpd-0.9.0.6
-data-dir: /usr/local/share/hs-libmpd-0.9.0.6
-hs-libraries: HSlibmpd-0.9.0.6-4M6tZyLoNUrEJ5VQyWfvHZ
+import-dirs: /usr/local/lib/ghc/libmpd-0.9.0.7
+library-dirs: /usr/local/lib/ghc/libmpd-0.9.0.7
+              /usr/local/lib/i386-openbsd-ghc-8.2.2
+data-dir: /usr/local/share/hs-libmpd-0.9.0.7
+hs-libraries: HSlibmpd-0.9.0.7-F2ZfiW69JTD1yGu4DIm545
 depends:
-    attoparsec-0.13.0.1-8953826c212c049a5286a9aadeb21f07
-    base-4.8.2.0-6d41353bf1900ecbb9b02a306c286c36
-    bytestring-0.10.6.0-0aa78e663f1d7b0d4f434cabb130075c
-    containers-0.5.6.2-72662c7d6dea4fa8c95128efb85ebc60
-    data-default-0.5.1-a67e419a5a4eb94e7b5c54e6097574e3
-    filepath-1.4.0.0-59267d26bde9029c896503f5d82794cc
-    mtl-2.2.1-05005bb32df8fbad260aa2bc8c4b64aa
-    network-2.6.2.1-3b665743d23d24bea9ea15fe12214a85
-    old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
-    text-1.2.1.3-b81318aa9c5f332f4a693000ebc8a335
-    time-1.5.0.1-7f6e7d3125c12e9efdc302bc6ee0a210
-    utf8-string-1.0.1.1-ff5d500075ea727c57bc4bda54a99b0c
-haddock-interfaces: /usr/local/share/doc/hs-libmpd-0.9.0.6/html/libmpd.haddock
-haddock-html: /usr/local/share/doc/hs-libmpd-0.9.0.6/html
+    base-4.10.1.0 attoparsec-0.13.0.1-37w4jz2uUXs3bEMk7HIEHV
+    bytestring-0.10.8.2 containers-0.5.10.2 filepath-1.4.1.2
+    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
+    old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9
+    text-1.2.1.3-5I6D6Lq0QEU97eY5wqs6DJ
+    data-default-0.5.1-H8DtWiIYInLGBIshsVPXQj
+    network-2.6.2.1-EN7QebdZTnQLy4O4vi1CmV
+    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO time-1.8.0.2
+abi-depends: base-4.10.1.0=3c10740f6cf9df7b9dca6d01ba411ea7
+             attoparsec-0.13.0.1-37w4jz2uUXs3bEMk7HIEHV=cf5930b7ba496a67deeecdd79f0f6361
+             bytestring-0.10.8.2=3f834c69e2158c4ad5032b0346c29480
+             containers-0.5.10.2=a2c92baf4a812b005ca4fa7f0772cd30
+             filepath-1.4.1.2=ef9a1704901889a61779624199ca7499
+             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=ff60e0c200c475a016137ee0a9ed1f03
+             old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9=a09774905d29698e6c89ba4927e5c216
+             text-1.2.1.3-5I6D6Lq0QEU97eY5wqs6DJ=5ca4db1764ff5f5e0d9e99e51b5e0b7d
+             data-default-0.5.1-H8DtWiIYInLGBIshsVPXQj=6811794d1235d9b9da499329f2cc855a
+             network-2.6.2.1-EN7QebdZTnQLy4O4vi1CmV=8851adc1c0835b2434fe123b5bcd5394
+             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=94b37fd4127634f98e4707fb4e4efd89
+             time-1.8.0.2=4e7e761020e68f00617832ab1b4f94d5
+haddock-interfaces: /usr/local/share/doc/hs-libmpd-0.9.0.7/html/libmpd.haddock
+haddock-html: /usr/local/share/doc/hs-libmpd-0.9.0.7/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
+
